==> ScriptDeploy-0.1.tar: ScriptDeploy/method.install.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/ScriptDeploy/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

	//$db =& $gCms->GetDb();
//	


	// mysql-specific, but ignored by other database
	$taboptarray = array('mysql' => 'TYPE=MyISAM');

	$dict = NewDataDictionary($db);
	
////
// Creat btn table
////
	// table schema description
	$flds = "
		ID I KEY AUTO,
		ScriptSet C(255)
		";


	// create it. This should do error checking, but I'm a lazy sod.
	$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_scriptdeploy_scriptnames",
			$flds, $taboptarray);
	$dict->ExecuteSQLArray($sqlarray);
	
	
////
// Creat btn table
////
	$flds = "
		ID I KEY,
		TemplateID I,
		Minify I,
		maxAge I,
		pathOption C(255),
		scriptType C(3),
		scriptSize I
		";

	// create it. This should do error checking, but I'm a lazy sod.
	$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_scriptdeploy_scriptoptions",
			$flds, $taboptarray);
	$dict->ExecuteSQLArray($sqlarray);
	
	
	
////
// Creat btn table
////
	$flds = "
		ID I,
		ScriptIs X2
		";

	// create it. This should do error checking, but I'm a lazy sod.
	$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_scriptdeploy_scriptparts",
			$flds, $taboptarray);
	$dict->ExecuteSQLArray($sqlarray);
	
////
// Creat btn table
////
	$flds = "
		ID I KEY AUTO,
		GrouptSet C(255),
		GrouptType C(3)
		";

	// create it. This should do error checking, but I'm a lazy sod.
	$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_scriptdeploy_group",
			$flds, $taboptarray);
	$dict->ExecuteSQLArray($sqlarray);
////
// Creat btn table
////
	$flds = "
		GrouptSetID I,
		ScriptID I
		";

	// create it. This should do error checking, but I'm a lazy sod.
	$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_scriptdeploy_groupassignment",
			$flds, $taboptarray);
	$dict->ExecuteSQLArray($sqlarray);



$this->SetPreference('debugIT', '0');

//include(dirname(__FILE__).'/action.matchFEUnCAL.php');	
	// put mention into the admin log
	$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('installed',$this->GetVersion()));

?>

==> ScriptDeploy-0.3.tar: ScriptDeploy/method.install.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/ScriptDeploy/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

	//$db =& $gCms->GetDb();
	$taboptarray = array('mysql' => 'TYPE=MyISAM');

	$dict = NewDataDictionary($db);
	
	$flds = "
		ID I KEY AUTO,
		ScriptSet C(255)
		";

	$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_scriptdeploy_scriptnames",
			$flds, $taboptarray);
	$dict->ExecuteSQLArray($sqlarray);

	$flds = "
		ID I KEY,
		TemplateID I,
		Minify I,
		maxAge I,
		pathOption C(255),
		notes C(255),
		scriptType C(3),
		MediaType C(255),
		scriptSize I
		";

	$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_scriptdeploy_scriptoptions",
			$flds, $taboptarray);
	$dict->ExecuteSQLArray($sqlarray);

	$flds = "
		ID I,
		ScriptIs X2
		";

	$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_scriptdeploy_scriptparts",
			$flds, $taboptarray);
	$dict->ExecuteSQLArray($sqlarray);

	$flds = "
		ID I KEY AUTO,
		GrouptSet C(255),
		GrouptType C(3)
		";

	$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_scriptdeploy_group",
			$flds, $taboptarray);
	$dict->ExecuteSQLArray($sqlarray);

	$flds = "
		GrouptSetID I,
		ScriptID I,
		ScriptORDER I
		";

	$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_scriptdeploy_groupassignment",
			$flds, $taboptarray);
	$dict->ExecuteSQLArray($sqlarray);

	$this->SetPreference('debugIT', '0');
	// put mention into the admin log
	$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('installed',$this->GetVersion()));

?>
